@@ -49,7 +49,7 @@ class _BaseContentAPI:
         except CantPullFromAPI:
             pass
         else:
-            cache.set(self.cache_key, data, None)
+            cache.set(self.cache_key, data, 1800)
 
     def get_data(self):
         data = cache.get(self.cache_key)
